#
# spec file for package timewarrior
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           timewarrior
Version:        1.7.1
Release:        1.2
Summary:        Command line time tracker
License:        MIT
Group:          Productivity/Office/Organizers
URL:            https://timewarrior.net/
Source:         https://github.com/GothenburgBitFactory/timewarrior/releases/download/v%{version}/timew-%{version}.tar.gz
Patch0:         timewarrior-build-compare.patch
BuildRequires:  %{rubygem asciidoctor}
BuildRequires:  cmake >= 2.8
BuildRequires:  gcc-c++ >= 6.1

%description
Timewarrior is a command line time tracking application, which allows you to
record time spent on activities.

%prep
%setup -q -n timew-%{version}
%patch0 -p1

%build
%cmake \
	-DTIMEW_DOCDIR=%{_datadir}/%{name} \
	.
%cmake_build

%install
%cmake_install
pushd %{buildroot}%{_datadir}/%{name}
rm -fv AUTHORS ChangeLog COPYING DCO INSTALL LICENSE README.md docker-compose.yml
chmod -v a+x ext/* holidays/refresh
sed -i 's|#!/usr/bin/env python3|#!/usr/bin/python3|' ext/* holidays/refresh
popd

%files
%license LICENSE
%doc ChangeLog AUTHORS README.md
%{_bindir}/timew
%{_mandir}/man1/timew.*
%{_mandir}/man1/timew-*
%{_mandir}/man7/timew-*
%{_datadir}/%{name}

%changelog
* Wed Jan 17 2024 Benedikt Fein <benedikt.fein@gmail.com>
- Update to 1.7.1
  * #580    internal parsing of tags starting with number broken
  * #582    Retrieval of intervals with tags containing hyphens is broken
  * #583    README - Update build instructions
* Tue Jan  2 2024 Benedikt Fein <benedikt.fein@gmail.com>
- Update to 1.7.0
  * #205    Wrap annotations in summary
  * #493    :lastweek doesn't count last Sunday
  * #494    Expand annotations in summary
  * #566    Set table width dynamically to terminal width
  * #573    Filter summary based on ids
  * #576    Fix quoting of tags in DOM output
  * Add ':today' hint
  * Refactor holidays/refresh script
  * Update task-timewarrior-hook script to
    87a3426d8153f92aaee2edf36b2de62e48c4de0e
- Update URL to timewarrior.net
* Wed Sep 27 2023 Benedikt Fein <benedikt.fein@gmail.com>
- Update to 1.6.0
  * #529    Fix summary truncating multibyte characters in long annotations
  * #531    Update CONTRIBUTING.md to use branch 'develop' instead of 'dev'
  * #535    Adding completion for fish shell
  * #538    Fix man page build for out-of-source builds
  * #540    reports should end at current time if a task is still running
  * #547    AtomicFile: Operate on the target of symlinks
  * #551    Add retag command
  * #552    Extend XDG support to macOS
  * #553    Configurability of CMake install directories
  * #554    Update documentation for command 'retag'
  * Use local man pages in tests
  * Cleanup CMake files
  * Update project to C++17
- Drop timewarrior-out-of-source-man-pages.patch since it has been integrated
  upstream with #538.
* Wed May  3 2023 Benedikt Fein <benedikt.fein@gmail.com>
- Update to 1.5.0
  * #361    Improve documentation
  * #389    Extend summary configuration
  * #489    First execution creates database regardless of confirmation response
  * #403    Remove incorrect output stating that an empty interval was recorded
  * #406    Clarify minimal value for 'epoch' as date value
  * #408    Update documentation of hint `:all`
  * #437    Minor AtomicFile cleanup
  * #439    Show error message if command track is called with an id
  * #441    Return report return code
  * #444    Improve documentation on annotations
  * #450    Report 'totals.py' does not display data when no time range specified
  * #458    Add man documentation for configuring tag colors.
  * #463    Add colors to summary
  * #466    Ignore empty exclusion ranges
  * #468    Refactor interval filtering
  * #469    Do not leak IntervalFilters in IntervalFilterAndGroup
  * #470    Do not leak filter in IntervalFilterFirstOf
  * #474    Make display of ids and annotations in summary report configurable
  * #477    Add configurable default range for reports
  * #478    Add support for XDG Base Directory specification on Unixes
  * #491    Tracking an interval in the future while actively tracking time results in a database inconsistency
  * #505    Report 'totals.py' does not truncate intervals to report range
  * #510    Export intervals by IDs
  * #512    help.t fails on alpine with mandoc package
  * Add option '--details' to 'test/problems' script
- Added timewarrior-out-of-source-man-pages.patch
- Update to 1.4.3
  * #159    Tags enclosed in escaped double-quotes are not handled correctly
  * #379    CmdSummary: Fix calculation of display start in summary table
  * #387    Fixed URL for tarball download
  * #390    dom.tracked.X.tag.Y always returns dom.tracked.1.tag.Y
  * #393    Update dark_blue.theme
  * #398    test: Thread.isAlive() -> Thread.is_alive()
  * #410    Replace roff man pages with asciidoctor
  * #411    Transfer platform testing from Travis CI to GitHub Actions
  * #416    Internal error. Failed encode / decode check when doing undo
  * #419    Links not preserved over linebreaks in man page
  * #422    Internal error. Failed encode / decode check.
  * Width determination of Unicode characters now works for up to
    Unicode 11 (from Unicode 5). Emojis are correctly displayed.
  * Fix test `summary.t` for single-digit weeks
* Thu Dec 17 2020 Michael Bryant <shadow53@shadow53.com> - 1.4.2
- Removed missing doc files from specfile
- Update to 1.4.2, skipping over 1.3.0, 1.4.0, 1.4.1
  * #377    make install with error due to missing file `COPYING`
  * #378    Summary with `:all` hint is empty for open interval
  * #126    DOM-Query for ids
  * #188    DOM-Query for tags
  * #206    Add :all hint
  * #241    Allow continue by tag.
  * #258    make error FS.cpp on freebsd 12.1
  * #307    Introduce 'journal.size' configuration item
  * #309    unicode input causes indefinite hang for commands like day or month
  * #331    start command adjust
  * #333    Summary command fails with `:all` hint
  * #335    Update docs links from taskwarrior.org to timewarrior.net
  * #351    Stop failed to close currently tracking interval
  * #364    Entering an open interval with future date causes assertion error
  * #372    Empty intervals are not deleted in `:adjust` overlap resolution
  * #259    Migrate to python 3
  * #270    Stop with id should suggest modify command
  * #275    Change `timew help intervals` to `timew help ranges` in help summary
  * #278    New hint :fortnight added
  * #284    tags.data modification date updated when file is not modified
  * #285    Pass record id to extensions
  * #290    trying to track something that would be before epoch fails silently, corrupting database
  * #293    filtering by tag can produce wrong ids
  * #298    Add current version of bash-completion
* Thu Feb  6 2020 Ondřej Súkup <mimi.vx@gmail.com>
- cleanup specfile
* Thu Dec 26 2019 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Update to 1.2.0. Full changelog available at https://github.com/GothenburgBitFactory/timewarrior/blob/1.2.0/ChangeLog
- Changed source url to GitHub
* Mon Mar 18 2019 Michal Vyskocil <mvyskocil@opensuse.org>
-  Update to 1.1.1
  - Taskwarrior integration hook now uses a project 'Home.Garden' as a single
    tag 'Home.Garden' as well as individual 'Home', 'Garden' tags.
  - Taskwarrior integration hook now stops the clock in more situations, such
    as deleting or waiting a task.
  - The 'tags' command now supports filters.
  - New date names supported (see 'timew help date' or 'man timew').
  - Timewarrior and Taskwarrior now use the same date handling.
  - The 'continue' command can resume tracking by @id.
  - When specifying a time without a date (e.g. '10:00am'), the day is assumed
    to be today, and is no longer projected back in time.
* Wed Nov  9 2016 olaf@aepfle.de
- Initial version 1.0.0
  timewarrior-build-compare.patch
